catscan
=======

Investigate wtf you were working on... where is that damn file?

Installation
------------

From the project root directory::

    $ python setup.py install
    $ catscan-install

Usage
-----

Simply run it with something that might be in the file, and it will check through files opened in sessions opened in the last 24 hours::

    $ catscan "successfully installed"

Use --help/-h to view info on the arguments::

    $ catscan --help

Release Notes
-------------

:0.0.1:
    Project created
